@@ -501,6 +501,8 @@ class InstallationDirective(SphinxDirective):
 		Create the installation node.
 		"""
 
+		assert self.env.app.builder is not None
+
 		if self.arguments:
 			self.options["project_name"] = self.arguments[0]
 
@@ -645,7 +647,7 @@ def copy_asset_files(app: Sphinx, exception: Optional[Exception] = None):
 	if exception:  # pragma: no cover
 		return
 
-	if app.builder.format.lower() != "html":
+	if app.builder is None or app.builder.format.lower() != "html":
 		return
 
 	static_dir = PathPlus(app.outdir) / "_static"
