@@ -718,6 +718,15 @@ class HTMLRegressionFixture(FileRegressionFixture):
 		for div in page.select("div.sphinxsidebar"):
 			div.extract()
 
+		if sphinx.version_info >= (4, 3):  # pragma: no cover
+			for div in page.select("span.w"):
+				div.extract()
+			for div in page.select("span.p"):
+				if div.string == '=':
+					sibling = div.next_sibling
+					div.replace_with('')
+					sibling.replace_with(f"= {sibling.text}")
+
 		kwargs.pop("encoding", None)
 		kwargs.pop("extension", None)
 
