@@ -89,7 +89,7 @@ def copy_asset_files(app: Sphinx, exception: Optional[Exception] = None) -> None
 	if exception:  # pragma: no cover
 		return
 
-	if app.builder.format.lower() != "html":
+	if app.builder is None or app.builder.format.lower() != "html":
 		return
 
 	# style = StringList([
@@ -129,7 +129,7 @@ copy_assets = deprecated(
 @metadata_add_version
 def setup(app: Sphinx) -> SphinxExtMetadata:
 	"""
-	Setup :mod:`sphinx_toolbox.sphinx_panels_tabs`.
+	Setup :mod:`sphinx_toolbox.tweaks.sphinx_panels_tabs`.
 
 	:param app: The Sphinx application.
 	"""
